# aiogrouper

This is a library for interacting with Internet2's Grouper in asynchronous code.

You may also be interested in [Robert Bradley](https://github.com/rb12345)'s
[grouper_ws](https://github.com/rb12345/grouper_ws) package on which this was
based.

